# btrdb

These are BTrDB Bindings for Python allowing you painless and productive access to the Berkeley Tree Database (BTrDB).  BTrDB is a time series database focusing on blazing speed with respect to univariate time series data at the nanosecond scale.

Please see the full documentation at: [https://btrdb.readthedocs.io/en/latest/](https://btrdb.readthedocs.io/en/latest/) particularly the quick [start guide](https://btrdb.readthedocs.io/en/latest/quick-start.html)
